% 

% -- File Directories   
figdir = 'fig/';
outdir = 'out/';
matdir = 'mat/';
mcmcdir = 'mcmc/';


% Model Name
mod_name = '_baseline';

cor_threshold = 0.25;

% Load Individual Elements
fstr = [mcmcdir 'pwcorr_del50U_draws' mod_name];load(fstr);
fstr = [mcmcdir 'pwcorr_del50Y_draws' mod_name];load(fstr);
fstr = [mcmcdir 'pwcorr_U_draws' mod_name];load(fstr);
fstr = [matdir 'country_code']; load(fstr);
n_c = size(country_code,1);
n_rep = size(pwcorr_del50U_draws,2);

pct = [0.05 0.16 0.50 0.85 0.95]';
pwcorr_del50Y_summary = pw_corr_summary(pwcorr_del50Y_draws,pct,n_c,n_rep);
pwcorr_del50U_summary = pw_corr_summary(pwcorr_del50U_draws,pct,n_c,n_rep);
pwcorr_U_summary = pw_corr_summary(pwcorr_U_draws,pct,n_c,n_rep);

% Write Posterior Means To CSV Files
outfile_name = [outdir 'pwcorr_del50U_summary' mod_name '.csv'];
fileID = fopen(outfile_name,'w');
prt_p_summary(pwcorr_del50U_summary,country_code,fileID,pct);
 
outfile_name = [outdir 'pwcorr_U_summary' mod_name '.csv'];
fileID = fopen(outfile_name,'w');
prt_p_summary(pwcorr_U_summary,country_code,fileID,pct);
 
outfile_name = [outdir 'pwcorr_del50Y_summary' mod_name '.csv'];
fileID = fopen(outfile_name,'w');
prt_p_summary(pwcorr_del50Y_summary,country_code,fileID,pct);

% Posterior Mean
pm_del50U = squeeze(pwcorr_del50U_summary(:,:,1));
pm_del50Y = squeeze(pwcorr_del50Y_summary(:,:,1));
pm_U = squeeze(pwcorr_U_summary(:,:,1));

fstr = [matdir 'country']; load(fstr);
fstr = [matdir 'country_code']; load(fstr);
n_c = size(country_code,1);

% Correlations
C = pm_del50U;   % Correlations to use
Cvec = C(2:end,1);
for i = 2:n_c-1;
    Cvec = [Cvec;C(i+1:end,i)];
end;

% Count the number of Correlations > 0.25
kk = 0;
kk1 = 0;
for i = 1:n_c
    if i == 1;
        tmp = C(2:end,1);
    elseif i == n_c;
        tmp = C(1:end-1,end);
    else;
        tmp = [C(1:i-1,i);C(i+1:end,i)];
    end;
    jj = sum(abs(tmp) > 0.25);
    kk1 = kk1+jj;
    if jj == 0;
        kk = kk+1;
        str = char(country_code(i));
        str2 = char(country(i));
        fprintf([str ': ' str2 ':  %3i \n'],jj);
    end;
end;

% Read in Distances
umdir = ['../data/'];
%Cdist = readmatrix([umdir 'distmat.csv']);
tmp = readtable([umdir 'distmat.csv']);
Cdist = table2array(tmp);

Cdvec = Cdist(2:end,1);
for i = 2:n_c-1;
    Cdvec = [Cdvec;Cdist(i+1:end,i)];
end;

% Compute Correlation between Distance and pairwise correlation
jjj = Cvec > 0.25;
corr(Cdvec,Cvec)
corr(Cdvec(jjj==1),Cvec(jjj==1))

ax_fs = 30;
histogram(Cvec,'Normalization','probability');
ax = gca;
ax.FontSize = ax_fs;
figure_to_png(figdir,['histogram_crosscorr_cij' mod_name]);
close(gcf);
mean(Cvec > 0.25)

pct = [0.05 0.16 0.50 0.85 0.95]';
Cvec_pct = pctile(Cvec,pct);

A = tril(C,-1) + triu(C,1);
A = A.*(A > cor_threshold);

% Drop Nodes with no connections
B = sum(abs(A))';
II = B > 0.01;
A0 = A(II==1,II==1);
c0 = country_code(II==1);
nc_0 = size(A0,1);



G0=graph(A0,c0);
tmp = table2array(G0.Edges(:,2));
tmp = 7*tmp;
p=plot(G0,'NodeLabel',G0.Nodes.Name,'LineWidth',tmp);
ax = gca;
ax.FontSize = 20;
figure_to_png(figdir,['Corr_0' mod_name]);
close(gcf);


% 
ilist_isolated = country_code(II==0);
i_isolated = (II==0);
ilist_Asia1 = {'THA';'SGP';'TWN';'HKG';'KOR';'MYS'};
ilist_Asia2 = {'MLI';'MMR';'LKA';'CHN';'IDN';'VNM';'LAO';'IND';'PAN'};
ilist_Soviet = {'HUN';'SRB';'BGR';'HRV';'RUS';'ROU'};
ilist_AS = {'AUS';'CAN';'GBR';'NZL';'USA'};
ilist_Europe = {'FIN';'CHE';'NOR';'DNK';'SWE';'NLD';'ITA';'BEL';'FRA';'GRC'};
ilist_Pairs = {'DEU';'AUT';'ESP';'PRT';'SYR';'YEM';'POL';'DOM'}; 

g_list = ilist_Asia1;
i_g = zeros(nc_0,1);
nn = size(g_list,1);
for j = 1:nn;
    ss = char(g_list(j));
    jj = colnumber(ss,c0);
    if jj > 0;
      i_g(jj) = 1;
    end;
end;
i_Asia1 = i_g;

g_list = ilist_Asia2;
i_g = zeros(nc_0,1);
nn = size(g_list,1);
for j = 1:nn;
    ss = char(g_list(j));
    jj = colnumber(ss,c0);
    if jj > 0;
      i_g(jj) = 1;
    end;
end;
i_Asia2 = i_g;

g_list = ilist_AS;
i_g = zeros(nc_0,1);
nn = size(g_list,1);
for j = 1:nn;
    ss = char(g_list(j));
    jj = colnumber(ss,c0);
    if jj > 0;
      i_g(jj) = 1;
    end;
end;
i_AS = i_g;

g_list = ilist_Europe;
i_g = zeros(nc_0,1);
nn = size(g_list,1);
for j = 1:nn;
    ss = char(g_list(j));
    jj = colnumber(ss,c0);
    if jj > 0;
      i_g(jj) = 1;
    end;
end;
i_Europe = i_g;

g_list = ilist_Soviet;
i_g = zeros(nc_0,1);
nn = size(g_list,1);
for j = 1:nn;
    ss = char(g_list(j));
    jj = colnumber(ss,c0);
    if jj > 0;
      i_g(jj) = 1;
    end;
end;
i_Soviet = i_g;

g_list = ilist_Pairs;
i_g = zeros(nc_0,1);
nn = size(g_list,1);
for j = 1:nn;
    ss = char(g_list(j));
    jj = colnumber(ss,c0);
    if jj > 0;
      i_g(jj) = 1;
    end;
end;
i_Pairs = i_g;

i_Other = (i_Asia1+i_Asia2+i_AS+i_Europe+i_Soviet+i_Pairs) == 0;


% List Countries in Each Group for Appendix
outfile_name = [outdir 'Country_Groups.csv'];
fileID = fopen(outfile_name,'w');
fprintf(fileID,'Asia_1 \n');
ilist = ilist_Asia1;
for i = 1:size(ilist,1);
    ss = char(ilist(i));
    fprintf(fileID,[ss '\n']);
end;

fprintf(fileID,'\n Asia_2 \n');
ilist = ilist_Asia2;
for i = 1:size(ilist,1);
    ss = char(ilist(i));
    fprintf(fileID,[ss '\n']);
end;

fprintf(fileID,'\n Soviet-bloc \n');
ilist = ilist_Soviet;
for i = 1:size(ilist,1);
    ss = char(ilist(i));
    fprintf(fileID,[ss '\n']);
end;

fprintf(fileID,'\n Anglo-Saxson \n');
ilist = ilist_AS;
for i = 1:size(ilist,1);
    ss = char(ilist(i));
    fprintf(fileID,[ss '\n']);
end;

fprintf(fileID,'\n Europe \n');
ilist = ilist_Asia2;
for i = 1:size(ilist,1);
    ss = char(ilist(i));
    fprintf(fileID,[ss '\n']);
end;

fprintf(fileID,'\n Other \n');
ilist = c0(i_Other==1);
for i = 1:size(ilist,1);
    ss = char(ilist(i));
    fprintf(fileID,[ss '\n']);
end;

fprintf(fileID,'\n Pairs \n');
ilist = ilist_Asia2;
for i = 1:size(ilist,1);
    ss = char(ilist(i));
    fprintf(fileID,[ss '\n']);
end;

fprintf(fileID,'\n Isolated \n');
ilist = ilist_isolated;
for i = 1:size(ilist,1);
    ss = char(ilist(i));
    fprintf(fileID,[ss '\n']);
end;




A_Asia1 = A0(i_Asia1==1,i_Asia1==1);
c_Asia1 = c0(i_Asia1==1);
G_Asia1=graph(A_Asia1,c_Asia1);

A_Asia2 = A0(i_Asia2==1,i_Asia2==1);
c_Asia2 = c0(i_Asia2==1);
G_Asia2=graph(A_Asia2,c_Asia2);

A_AS = A0(i_AS==1,i_AS==1);
c_AS = c0(i_AS==1);
G_AS=graph(A_AS,c_AS);

A_Europe = A0(i_Europe==1,i_Europe==1);
c_Europe = c0(i_Europe==1);
G_Europe=graph(A_Europe,c_Europe);

A_Soviet = A0(i_Soviet==1,i_Soviet==1);
c_Soviet = c0(i_Soviet==1);
G_Soviet=graph(A_Soviet,c_Soviet);

A_Other = A0(i_Other==1,i_Other==1);
c_Other = c0(i_Other==1);
G_Other=graph(A_Other,c_Other);

A_Pairs = A0(i_Pairs==1,i_Pairs==1);
c_Pairs = c0(i_Pairs==1);
G_Pairs=graph(A_Pairs,c_Pairs);

% Average Values of correlations
mean(table2array(G_Asia1.Edges(:,2)))
mean(table2array(G_Asia2.Edges(:,2)))
mean(table2array(G_Soviet.Edges(:,2)))
mean(table2array(G_AS.Edges(:,2)))
mean(table2array(G_Europe.Edges(:,2)))
mean(table2array(G_Other.Edges(:,2)))
mean(table2array(G_Pairs.Edges(:,2)))


%figure;
figure_10;
